about summary refs log tree commit diff stats
path: root/modules/home.legacy/pkgs
diff options
context:
space:
mode:
Diffstat (limited to '')
-rw-r--r--modules/home.legacy/pkgs/default.nix26
1 files changed, 2 insertions, 24 deletions
diff --git a/modules/home.legacy/pkgs/default.nix b/modules/home.legacy/pkgs/default.nix
index 859aea36..e9181b99 100644
--- a/modules/home.legacy/pkgs/default.nix
+++ b/modules/home.legacy/pkgs/default.nix
@@ -1,24 +1,11 @@
 {
   pkgs,
   lib,
-  config,
   nixosConfig,
   ...
 }:
 # TODO: Remove this whole file, and move each package to a separate module. <2024-11-16>
 with pkgs; let
-  neorgFinal =
-    neorg.override
-    {
-      defaultNeorgProjectDir = config.programs.nixvim.plugins.neorg.settings.load."core.dirman".config.workspaces.projects;
-      allProjectsNewline = config.soispha.taskwarrior.projects.projects_newline;
-      allProjectsComma = config.soispha.taskwarrior.projects.projects_comma;
-      allProjectsPipe = config.soispha.taskwarrior.projects.projects_pipe;
-      allWorkspaces = config.programs.nixvim.plugins.neorg.settings.load."core.dirman".config.workspaces;
-      xdgConfigHome = config.xdg.configHome;
-      xdgDataHome = config.xdg.dataHome;
-    };
-
   Gui = {
     Terminals = [
       alacritty # default terminal
@@ -65,9 +52,9 @@ with pkgs; let
       ];
 
       Firefox = [
         # `neorg` handles the integration between Firefox profiles and task
         # contexts
-        neorgFinal
+        pkgs.tskm
       ];
     };
 
@@ -158,15 +145,6 @@ with pkgs; let
       else builtins.attrValues x
     else [x];
 in {
-  options.soispha.programs.neorg = {
-    package = lib.mkOption {
-      type = lib.types.package;
-      default = neorgFinal;
-      description = ''
-        The neorg package to use.
-      '';
-    };
-  };
   config.home.packages =
     []
     ++ (with builtins;
@@ -65,9 +52,9 @@ with pkgs; let
 
       Firefox = [
-        # `neorg` handles the integration between Firefox profiles and task
+        # `tskm` handles the integration between Firefox profiles and task
         # contexts